CHANGES
=======

0.1.1 (2014.01.18)
------------------

* Clear run-on-commit hooks even if one raises an exception. Thanks akaariai.


0.1 (2014.01.18)
----------------

* Initial working version; support for SQLite3, PostgreSQL, MySQL.
